The *check-repos.ps1* Script
===========================

This PowerShell script verifies the data integrity of all Git repositories in a folder.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/check-repos.ps1 [[-parentDir] <String>] [<CommonParameters>]

-parentDir <String>
    Specifies the file path to the parent folder
    
    Required?                    false
    Position?                    1
    Default value                "$PWD"
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./check-repos.ps1 C:\Repos
⏳ Checking parent folder 📂C:\Repos...    16 subfolders
⏳ Checking 📂rust repository (1/16)...
...
✅ Checked all 16 Git repos in 📂C:\Repos in 356s.

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Checks Git repositories
.DESCRIPTION
	This PowerShell script verifies the data integrity of all Git repositories in a folder.
.PARAMETER parentDir
	Specifies the file path to the parent folder
.EXAMPLE
	PS> ./check-repos.ps1 C:\Repos
	⏳ Checking parent folder 📂C:\Repos...    16 subfolders
	⏳ Checking 📂rust repository (1/16)...
	...
	✅ Checked all 16 Git repos in 📂C:\Repos in 356s.
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$parentDir = "$PWD")

try {
	$stopWatch = [system.diagnostics.stopwatch]::startNew()

	$parentDirName = (Get-Item "$parentDir").Name
	Write-Host "⏳ Checking parent folder 📂$parentDir...       " -noNewline
	if (-not(Test-Path "$parentDir" -pathType container)) { throw "Can't access folder: $parentDir" }
	$folders = (Get-ChildItem "$parentDir" -attributes Directory)
	$numFolders = $folders.Count
	"$numFolders subfolders"

	[int]$step = 1
	foreach ($folder in $folders) {
		"`n⏳ Checking 📂$folder repository ($step/$numFolders)..."
		& "$PSScriptRoot/check-repo.ps1" "$folder"
		$step++
	}

	[int]$elapsed = $stopWatch.Elapsed.TotalSeconds
	"✅ Checked all $numFolders Git repos in 📂$parentDir in $($elapsed)s."
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:35)*
